@@ -3,7 +3,8 @@
 # WHP Password Encryption Update Script
 # This script enables password encryption for existing installations
 
-set -e  # Exit on any error
+set -eE  # Exit on any error, but allow us to handle them
+trap 'echo "Error on line $LINENO"' ERR
 
 KEY_FILE="/etc/whp/encryption.key"
 BACKUP_DIR="/root/whp-backups"
@@ -57,7 +58,7 @@ fi
 echo "🔄 Migrating existing passwords to encryption..."
 
 # Get list of users with passwords
-USERS=$(mysql -N -e "SELECT username FROM whp.user_passwords WHERE mysql_password IS NOT NULL AND mysql_password != ''")
+USERS=$(mysql -N -e "SELECT username FROM whp.user_passwords WHERE mysql_password IS NOT NULL AND LENGTH(mysql_password) > 0")
 
 if [ -z "$USERS" ]; then
     echo "ℹ️  No users found with stored passwords"
@@ -68,10 +69,15 @@ else
     for USERNAME in $USERS; do
         echo -n "   Processing $USERNAME... "
         
-        # Get current base64 encoded password
+        # Get current password and check if it's already encrypted
         CURRENT_PASSWORD=$(mysql -N -e "SELECT mysql_password FROM whp.user_passwords WHERE username = '$USERNAME'")
         
         if [ -n "$CURRENT_PASSWORD" ]; then
+            # Check if password is already encrypted (encrypted passwords are much longer)
+            if [ ${#CURRENT_PASSWORD} -gt 50 ]; then
+                echo "✅ Already encrypted, skipping"
+                continue
+            fi
             # Try to decode base64, fall back to treating as plaintext
             PLAINTEXT=""
             if echo "$CURRENT_PASSWORD" | base64 -d >/dev/null 2>&1; then
@@ -102,7 +108,7 @@ else
                     echo 'ERROR: ' . \$e->getMessage();
                     exit(1);
                 }
-            ")
+            " 2>&1 || true)
             
             if [[ $ENCRYPTED == ERROR:* ]]; then
                 echo "❌ Failed - ${ENCRYPTED#ERROR: }"
@@ -127,6 +133,7 @@ else
     echo "📊 Migration Summary:"
     echo "   ✅ Migrated: $MIGRATED users"
     echo "   ❌ Failed: $FAILED users"
+    echo "   ℹ️  Total processed: $(echo "$USERS" | wc -w) users"
     
     if [ $FAILED -gt 0 ]; then
         echo "⚠️  Some migrations failed. Check logs and use reset-user-password.sh if needed."
@@ -135,7 +142,7 @@ fi
 
 # Step 4: Migrate PostgreSQL passwords if any exist
 echo "🔄 Checking PostgreSQL passwords..."
-PG_USERS=$(mysql -N -e "SELECT username FROM whp.user_passwords WHERE postgresql_password IS NOT NULL AND postgresql_password != ''")
+PG_USERS=$(mysql -N -e "SELECT username FROM whp.user_passwords WHERE postgresql_password IS NOT NULL AND LENGTH(postgresql_password) > 0")
 
 if [ -n "$PG_USERS" ]; then
     echo "🔄 Migrating PostgreSQL passwords..."
@@ -148,6 +155,11 @@ if [ -n "$PG_USERS" ]; then
         CURRENT_PG_PASSWORD=$(mysql -N -e "SELECT postgresql_password FROM whp.user_passwords WHERE username = '$USERNAME'")
         
         if [ -n "$CURRENT_PG_PASSWORD" ]; then
+            # Check if password is already encrypted (encrypted passwords are much longer)
+            if [ ${#CURRENT_PG_PASSWORD} -gt 50 ]; then
+                echo "✅ Already encrypted, skipping"
+                continue
+            fi
             # Try to decode base64, fall back to treating as plaintext
             PG_PLAINTEXT=""
             if echo "$CURRENT_PG_PASSWORD" | base64 -d >/dev/null 2>&1; then
@@ -178,7 +190,7 @@ if [ -n "$PG_USERS" ]; then
                     echo 'ERROR: ' . \$e->getMessage();
                     exit(1);
                 }
-            ")
+            " 2>&1 || true)
             
             if [[ $PG_ENCRYPTED == ERROR:* ]]; then
                 echo "❌ Failed - ${PG_ENCRYPTED#ERROR: }"
